# Py Dep Graph

[![PyPI - Version](https://img.shields.io/pypi/v/py-dep-graph.svg)](https://pypi.org/project/py-dep-graph)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/py-dep-graph.svg)](https://pypi.org/project/py-dep-graph)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install py-dep-graph
```

## License

`py-dep-graph` is distributed under the terms of the GPL-2.0 license.